@@ -13,3 +13,6 @@ pub mod pyth;
 pub use accounts::InstructionsAccount;
 pub use bonfida_macros::{declare_id_with_central_state, BorshSize, InstructionsAccount};
 pub use borsh_size::BorshSize;
+
+#[cfg(feature = "benchmarking")]
+pub mod bench;
